@@ -1,12 +1,28 @@
-import datetime
+"""
+Contains class ecat2ii, used to write ecat information out to a nifti file, depends on
+`nibabel <https://nipy.org/nibabel/>`_ and  :func:`pypet2bids.read_ecat.read_ecat`.
 
+| *Authors: Anthony Galassi*
+| *Copyright OpenNeuroPET team*
+"""
+import datetime
 import nibabel
 import numpy
 import pathlib
 from pypet2bids.read_ecat import read_ecat
 import os
 import pickle
+import logging
 
+try:
+    import helper_functions
+except ModuleNotFoundError:
+    import pypet2bids.helper_functions as helper_functions
+
+
+#logger = helper_functions.logger('pypet2bids')
+
+logger = logging.getLogger('pypet2bids')
 
 def ecat2nii(ecat_main_header=None,
              ecat_subheaders=None,
@@ -18,8 +34,9 @@ def ecat2nii(ecat_main_header=None,
              save_binary=False,
              **kwargs):
     """
-    Converts an ECAT file into a nifti and a sidecar json, used in conjunction with read_ecat from pypet2bids.read_ecat.
-
+    Converts an ECAT file into a nifti and a sidecar json, used in conjunction with
+    :func:`pypet2bids.read_ecat.read_ecat`
+    
     :param ecat_main_header: the main header of an ECAT file
     :param ecat_subheaders: the subheaders for each frame of the ECAT file
     :param ecat_pixel_data: the imaging/pixel data from the ECAT file
@@ -31,7 +48,9 @@ def ecat2nii(ecat_main_header=None,
     :param kwargs: additional key value pairs that one wishes to add to the sidecar json accompanying a converted ECAT
         nii image
     :return: a nibabel nifti object if one wishes to muddle with the object in python and not in a .nii file
+
     """
+
     # if a nifti file/path is not included write a nifti next to the ecat file
     if not nifti_file:
         nifti_file = os.path.splitext(ecat_file)[0] + ".nii"
@@ -63,7 +82,7 @@ def ecat2nii(ecat_main_header=None,
     if kwargs.get('TimeZero', None):
         TimeZero = kwargs['TimeZero']
     else:
-        print("Metadata TimeZero is missing -- set to ScanStart or empty to use the scanning time as "
+        logger.warn("Metadata TimeZero is missing -- set to ScanStart or empty to use the scanning time as "
               "injection time")
 
     # get image shape
@@ -113,7 +132,11 @@ def ecat2nii(ecat_main_header=None,
             prompts.append(0)
             randoms.append(0)
 
-    final_image = img_temp * main_header['ECAT_CALIBRATION_FACTOR']
+    ecat_cal_units = main_header['CALIBRATION_UNITS']  # Header field designating whether data has already been calibrated
+    if ecat_cal_units==1:                              # Calibrate if it hasn't been already
+        final_image = img_temp * main_header['ECAT_CALIBRATION_FACTOR']
+    else:                            # And don't calibrate if CALIBRATION_UNITS is anything else but 1
+        final_image = img_temp
 
     qoffset_x = -1 * (
         ((sub_headers[0]['X_DIMENSION'] * sub_headers[0]['X_PIXEL_SIZE'] * 10 / 2) - sub_headers[0][
@@ -168,7 +191,7 @@ def ecat2nii(ecat_main_header=None,
 
     # TODO img_nii.header['scl_slope'] # this is a NaN array by default but apparently it should be the dose calibration
     #  factor img_nii.header['scl_inter'] # defaults to NaN array
-    img_nii.header['scl_slope'] = main_header['ECAT_CALIBRATION_FACTOR']
+    img_nii.header['scl_slope'] = 0
     img_nii.header['scl_inter'] = 0
     img_nii.header['slice_end'] = 0
     img_nii.header['slice_code'] = 0
