@@ -1,3 +1,18 @@
+"""
+This module contains methods used to read ecat files (\*.v), the primary method pulled/imported from this module
+is read_ecat which returns the contents of a singular ecat file divided into three parts:
+
+- main header
+- subheaders
+- pixel data
+
+The other functions primarily operate bitwise, so it's best not to use them outside of this module, unless you are a
+glutton or twisted in that sort of way.
+
+:Authors: Anthony Galassi
+:Copyright: Open NeuroPET team
+
+"""
 import json
 import os.path
 import struct
@@ -12,6 +27,7 @@ parent_dir = pathlib.Path(__file__).parent.resolve()
 code_dir = parent_dir.parent
 data_dir = code_dir.parent
 
+
 # collect ecat header maps, this program will not work without these as ECAT data varies in the byte location of its
 # data depending on the version of ECAT it was formatted with.
 try:
@@ -129,6 +145,9 @@ def get_header_data(header_data_map: dict, ecat_file: str = '', byte_offset: int
         header[variable_name] = struct.unpack(struct_fmt, raw_bytes)
         if clean and 'fill' not in variable_name.lower():
             header[variable_name] = filter_bytes(header[variable_name], struct_fmt)
+        if 'comment' in value and 'msec' in value['comment']:
+            # for entries that are in msec, convert to sec for PET BIDS json
+            header[variable_name] /= 1000
         read_head_position = relative_byte_position + byte_width
 
     return header, read_head_position
@@ -221,9 +240,10 @@ def read_ecat(ecat_file: str, calibrated: bool = False, collect_pixel_data: bool
     :param ecat_file: path to an ecat file, does not handle compression currently
     :param calibrated: if True, will scale the raw imaging data by the SCALE_FACTOR in the subheader and
     :param collect_pixel_data: By default collects the entire ecat, can be passed false to only return headers
-           CALIBRATION_FACTOR in the main header
+        CALIBRATION_FACTOR in the main header
 
     :return: main_header, a list of subheaders for each frame, the imagining data from the subheaders
+
     """
     if ".gz" in ecat_file:
         ecat_file = decompress(ecat_file)
